AnimEncoder

Trait AnimEncoder 

pub trait AnimEncoder {
    // Required method
    fn encode(&mut self) -> Result<Vec<u8>>;

    // Provided method
    fn save<P: AsRef<Path>>(&mut self, path: P) -> Result<()> { ... }
}
Something that can consume rendered frames and emit an encoded animation.

Required Methods

fn encode(&mut self) -> Result<Vec<u8>>

Encode all frames into the target format, returning the bytes.

Provided Methods

fn save<P: AsRef<Path>>(&mut self, path: P) -> Result<()>

Encode all frames and write them to path.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors